@@ -84,6 +84,7 @@ lazy_static! {
                 ("C98/USDT", 1_f64),
                 ("CAKE/USDT", 0.1_f64),
                 ("CELR/USDT", 10_f64),
+                ("CERE/USDT", 10_f64),
                 ("CFX/USDT", 10_f64),
                 ("CHR/USDT", 10_f64),
                 ("CHZ/USDT", 100_f64),
@@ -92,6 +93,7 @@ lazy_static! {
                 ("COMP/USDT", 0.01_f64),
                 ("CONV/USDT", 10_f64),
                 ("COTI/USDT", 1_f64),
+                ("CRO/USDT", 1_f64),
                 ("CRU/USDT", 0.01_f64),
                 ("CRV/USDT", 0.1_f64),
                 ("CSPR/USDT", 10_f64),
@@ -104,6 +106,8 @@ lazy_static! {
                 ("DOT/USDT", 1_f64),
                 ("DYDX/USDT", 0.1_f64),
                 ("EGLD/USDT", 0.1_f64),
+                ("ENJ/USDT", 1_f64),
+                ("ENS/USDT", 0.1_f64),
                 ("EOS/USDT", 1_f64),
                 ("ETC/USDT", 0.1_f64),
                 ("ETH/USDT", 0.01_f64),
@@ -122,9 +126,11 @@ lazy_static! {
                 ("HIVE/USDT", 1_f64),
                 ("HT/USDT", 1_f64),
                 ("ICP/USDT", 0.001_f64),
+                ("IMX/USDT", 1_f64),
                 ("IOST/USDT", 10_f64),
                 ("IOTX/USDT", 10_f64),
                 ("IRIS/USDT", 10_f64),
+                ("JASMY/USDT", 1_f64),
                 ("JST/USDT", 100_f64),
                 ("KAVA/USDT", 1_f64),
                 ("KEEP/USDT", 1_f64),
@@ -137,9 +143,14 @@ lazy_static! {
                 ("LRC/USDT", 1_f64),
                 ("LTC/USDT", 0.1_f64),
                 ("LUNA/USDT", 1_f64),
+                ("MAKITA/USDT", 0.1_f64),
+                ("MANA/USDT", 0.1_f64),
                 ("MASK/USDT", 0.1_f64),
                 ("MATIC/USDT", 10_f64),
+                ("MBABYDOGE/USDT", 100_f64),
+                ("MELON/USDT", 1_f64),
                 ("MINA/USDT", 0.1_f64),
+                ("MKISHU/USDT", 100_f64),
                 ("MKR/USDT", 0.001_f64),
                 ("MOVR/USDT", 0.01_f64),
                 ("MTL/USDT", 0.1_f64),
@@ -184,11 +195,13 @@ lazy_static! {
                 ("TFUEL/USDT", 10_f64),
                 ("THETA/USDT", 1_f64),
                 ("TLM/USDT", 1_f64),
+                ("TONCOIN/USDT", 0.1_f64),
                 ("TRIBE/USDT", 1_f64),
                 ("TRU/USDT", 10_f64),
                 ("TRX/USDT", 100_f64),
                 ("UNI/USDT", 1_f64),
                 ("VET/USDT", 100_f64),
+                ("VRA/USDT", 10_f64),
                 ("WAVES/USDT", 1_f64),
                 ("WAXP/USDT", 1_f64),
                 ("WSB/USDT", 0.001_f64),
